@@ -29,9 +29,13 @@
 typedef int socklen_t;
 #endif
 
+#ifdef HAVE_CONFIG_H
+#  include "../config.h"
+#endif
+
 int to_ip_port (const sockaddr_in *in, std::string &ip, int &port);
 
-class octave_udpport : public octave_base_value
+class octave_udpport : public OCTAVE_BASE_CLASS
 {
 public:
   octave_udpport (void);
@@ -79,7 +83,7 @@ public:
   dim_vector dims (void) const { static dim_vector dv(1, 1); return dv; }
 
   // use single copy of each udpport socket
-  octave_base_value * unique_clone (void) { count++; return this; }
+  octave_base_value * unique_clone (void) { OV_COUNT++; return this; }
 
  /**
   * overloaded methods to get properties
@@ -163,6 +167,10 @@ public:
 
 private:
   bool has_property(const std::string &name) const;
+  uint8_t *input_buffer;
+  int buffer_len;
+  int buffer_pos;
+  sockaddr_in read_addr;
 
   int fd;
   double timeout;
